aboutsummaryrefslogtreecommitdiff
path: root/scumm
diff options
context:
space:
mode:
authorEugene Sandulenko2004-02-18 05:20:47 +0000
committerEugene Sandulenko2004-02-18 05:20:47 +0000
commitcab9b2f34ad1f4bc42309c2280adca11bc4b727c (patch)
treeaeffae7354b1e56d403d275e0c3ed68a8a717172 /scumm
parent1f2ab0145bf11521d1cf34884b45db993a95ec5e (diff)
downloadscummvm-rg350-cab9b2f34ad1f4bc42309c2280adca11bc4b727c.tar.gz
scummvm-rg350-cab9b2f34ad1f4bc42309c2280adca11bc4b727c.tar.bz2
scummvm-rg350-cab9b2f34ad1f4bc42309c2280adca11bc4b727c.zip
INSANE debug output now can be turned ot in debug console
svn-id: r12926
Diffstat (limited to 'scumm')
-rw-r--r--scumm/scumm.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/scumm/scumm.h b/scumm/scumm.h
index 0a923ead55..3da2f48a3c 100644
--- a/scumm/scumm.h
+++ b/scumm/scumm.h
@@ -128,7 +128,8 @@ enum {
DEBUG_RESOURCE = 1 << 5, // Track resource loading / allocation
DEBUG_IMUSE = 1 << 6, // Track iMUSE events
DEBUG_SOUND = 1 << 7, // General Sound Debug
- DEBUG_ACTORS = 1 << 8 // General Actor Debug
+ DEBUG_ACTORS = 1 << 8, // General Actor Debug
+ DEBUG_INSANE = 1 << 9 // Track INSANE
};
@@ -139,7 +140,8 @@ static const dbgChannelDesc debugChannels[] = {
{"IMUSE", "Track iMUSE events", DEBUG_IMUSE},
{"RESOURCE", "Track resource loading/management", DEBUG_RESOURCE},
{"VARS", "Track variable changes", DEBUG_VARS},
- {"ACTORS", "Actor-related debug", DEBUG_ACTORS}
+ {"ACTORS", "Actor-related debug", DEBUG_ACTORS},
+ {"INSANE", "Track INSANE", DEBUG_INSANE}
};
struct MemBlkHeader {